WITH Ada.Text_IO;
PROCEDURE Copy_File IS
------------------------------------------------------------------------
--| Program copies its input file into its output file 
--| then closes the output file, re-opens it for input,  
--| and displays its contents on the screen.
--| Author: Michael B. Feldman, The George Washington University 
--| Last Modified: September 1998 
------------------------------------------------------------------------

  MaxName      : CONSTANT Positive := 80;
  SUBTYPE NameRange IS Positive RANGE 1..MaxName;

  InFileName   : String(NameRange):= (OTHERS => '#');
  OutFileName  : String(NameRange):= (OTHERS => '#');
  InNameLength : NameRange;
  OutNameLength: NameRange;
  InData       : Ada.Text_IO.File_Type;
  OutData      : Ada.Text_IO.File_Type;
  
  NextCh       : Character;

BEGIN -- Copy_File

  -- get input file name and open it
  Ada.Text_IO.Put(Item => "Please enter name of file to copy >");
  Ada.Text_IO.Get_Line(Item => InFileName, Last => InNameLength);
  Ada.Text_IO.Open  (File=>InData, Mode=>Ada.Text_IO.In_File, 
                     Name=>InFileName(1..InNameLength));

  -- get output file name and create it
  Ada.Text_IO.Put(Item => "Please enter name of the new file >");
  Ada.Text_IO.Get_Line(Item => OutFileName, Last => OutNameLength);
  Ada.Text_IO.Create(File=>OutData, Mode=>Ada.Text_IO.Out_File, 
                     Name=>OutFileName(1..OutNameLength));
                  
  -- copy input file to output file, character by character
  LOOP
    EXIT WHEN Ada.Text_IO.End_of_File(File => InData);
    LOOP
      EXIT WHEN Ada.Text_IO.End_of_Line(File => InData);

      Ada.Text_IO.Get(File => InData, Item => NextCh);
      Ada.Text_IO.Put(File => OutData, Item => NextCh);

    END LOOP;

    Ada.Text_IO.Skip_Line(File => InData);
    Ada.Text_IO.New_Line(File => OutData);
  END LOOP;

  Ada.Text_IO.Close(File => InData);
  Ada.Text_IO.Close(File => OutData);

  -- reopen the new file and display it on the screen
  Ada.Text_IO.Open(File=>InData, Mode=>Ada.Text_IO.In_File, 
                   Name=>OutFileName(1..OutNameLength));

  WHILE NOT Ada.Text_IO.End_of_File(File => InData) LOOP
    WHILE NOT Ada.Text_IO.End_of_Line(File => InData) LOOP

      Ada.Text_IO.Get(File => InData, Item => NextCh);
      Ada.Text_IO.Put(Item => NextCh);

    END LOOP;

    Ada.Text_IO.Skip_Line(File => InData);
    Ada.Text_IO.New_Line;
  END LOOP;

  Ada.Text_IO.Close(File => InData);

EXCEPTION

  WHEN Ada.Text_IO.Name_Error =>
    Ada.Text_IO.Put
      (Item => "File to copy doesn't exist in this directory!");
    Ada.Text_IO.New_Line;

END Copy_File;
