WITH Ada.Text_IO;
WITH Ada.Integer_Text_IO;
WITH Ada.Float_Text_IO;
PROCEDURE Multi_Payroll IS
----------------------------------------------------------------
--| Computes and displays gross pay and net pay for a number
--| of employees, given each employee's hourly rate and 
--| hours worked.
--| Author: M. B. Feldman, The George Washington University 
--| Last Modified: August 1998
----------------------------------------------------------------

  SUBTYPE NonNegFloat IS Float RANGE 0.0 .. Float'Last;

  TaxBracket : CONSTANT NonNegFloat := 100.00;
                                    -- maximum salary for no tax
  TaxRate :    CONSTANT NonNegFloat :=  0.15;   -- tax rate 

  NumEmp    : Positive;        -- inputs - number of employees
  Hours :     NonNegFloat;     -- hours worked, hourly rate
  HourlyRate: NonNegFloat;

  GrossPay:  NonNegFloat;      -- outputs - gross pay, net pay
  Tax:       NonNegFloat;
  NetPay:    NonNegFloat;

BEGIN -- Multi_Payroll

  Ada.Text_IO.Put ("Please enter number of employees > ");
  Ada.Integer_Text_IO.Get (Item => NumEmp);

  FOR CountEmp IN 1 .. NumEmp LOOP

    -- Enter Hours and HourlyRate
    Ada.Text_IO.Put (Item => "Employee number ");
    Ada.Integer_Text_IO.Put (Item => CountEmp, Width => 1);
    Ada.Text_IO. New_Line;
    Ada.Text_IO.Put (Item => "  Hours worked > ");
    Ada.Float_Text_IO.Get (Item => Hours);
    Ada.Text_IO.Put (Item => "  Hourly rate $");
    Ada.Float_Text_IO.Get (Item => HourlyRate);

    -- Compute gross salary
    GrossPay := Hours * HourlyRate;

    -- Compute net salary
    IF GrossPay > TaxBracket THEN
      Tax := TaxRate * (GrossPay - TaxBracket);
      NetPay := GrossPay - Tax;     -- Deduct a tax amount
    ELSE
      NetPay := GrossPay;           -- Deduct no tax
    END IF;

    -- Display Results
    Ada.Text_IO.Put (Item => "  Gross pay is $");
    Ada.Float_Text_IO.Put 
      (Item => GrossPay, Fore => 1, Aft => 2, Exp => 0);
    Ada.Text_IO.New_Line;
    Ada.Text_IO.Put (Item => "  Tax Deduction is $");
    Ada.Float_Text_IO.Put 
      (Item => Tax, Fore => 1, Aft => 2, Exp => 0);
    Ada.Text_IO.New_Line;
    Ada.Text_IO.Put (Item => " Net pay is $");
    Ada.Float_Text_IO.Put 
      (Item => NetPay, Fore => 1, Aft => 2, Exp => 0);
    Ada.Text_IO.New_Line;

  END LOOP;

END Multi_Payroll;
