WITH Ada.Text_IO;
WITH Ada.Text_IO.Editing;
WITH Ada.Float_Text_IO;
PROCEDURE Payroll_2 IS
----------------------------------------------------------------
--| Computes and displays gross pay and net pay given an hourly
--| rate and number of hours worked.  Deducts a tax of 15% of
--| gross salary exceeding $100.
--| Author: Michael Feldman, The George Washington University
--| Last Modified: July 1998
----------------------------------------------------------------
  TYPE Money IS DELTA 0.01 DIGITS 12;
  
  PACKAGE Money_In IS NEW Ada.Text_IO.Decimal_IO (Num => Money);
  PACKAGE Money_Out IS NEW Ada.Text_IO.Editing.Decimal_Output (Num => Money);

  TaxBracket : CONSTANT Money := 100.00;
                             -- maximum salary for no deduction
  TaxRate:     CONSTANT Money :=  0.15;   -- tax amount
 
  Hours:      Money; -- inputs - hours worked, hourly rate  
  HourlyRate: Money; 
  GrossPay:   Money; -- outputs - gross pay, net pay        
  Tax:        Money;
  NetPay:     Money; 
 
BEGIN -- Payroll_2

  -- Enter Hours and Rate   
  Ada.Text_IO.Put (Item => "Hours worked > ");
  Money_In.Get (Item => Hours);  
  Ada.Text_IO.Put (Item => "Hourly rate $");
  Money_In.Get (Item => HourlyRate);  
  Ada.Text_IO.New_Line;
 
  -- Compute gross salary
  GrossPay := Hours * HourlyRate;
 
  -- Compute tax and net salary 
  IF GrossPay > TaxBracket THEN
    Tax := TaxRate * (GrossPay - TaxBracket);
    NetPay := GrossPay - Tax;     -- Deduct a tax amount  
  ELSE
    NetPay := GrossPay;           -- Deduct no tax  
  END IF;
 
  -- Print Results         
  Ada.Text_IO.Put (Item => "Gross pay is");
  Money_Out.Put 
    (Item => GrossPay, 
     Pic => Ada.Text_IO.Editing.To_Picture ("$$_$$$_$$9.99CR"));
  Ada.Text_IO.New_Line;
  Ada.Text_IO.Put (Item => "TaxDeduction is");
  Money_Out.Put 
    (Item => Tax, 
     Pic => Ada.Text_IO.Editing.To_Picture ("$$_$$$_$$9.99CR"));
  Ada.Text_IO.New_Line;
  Ada.Text_IO.Put (Item => "Net pay is");
  Money_Out.Put 
    (Item => NetPay, 
     Pic => Ada.Text_IO.Editing.To_Picture ("$$_$$$_$$9.99CR"));
  Ada.Text_IO.New_Line;

END Payroll_2;
