WITH Ada.Text_IO;
WITH Ada.Float_Text_IO;
PROCEDURE Worm_and_Apple IS
--------------------------------------------------------------
--| Displays distances between a worm and an apple.  The worm
--| keeps reducing the distance by its body length until it is
--| close enough to bite the apple.
--| Author: M. B. Feldman, The George Washington University
--| Last Modified: August 1998
--------------------------------------------------------------

  SUBTYPE NonNegFloat IS Float RANGE 0.0 .. Float'Last;

  WormLength: CONSTANT NonNegFloat := 8.5;
                             -- worm body length in CM

  InitialDist: NonNegFloat;  -- input - starting distance
                             --   of worm from apple
  Distance:    NonNegFloat;  -- output - diminishing distance
                             --   between worm and apple

BEGIN -- Worm_and_Apple

  Ada.Text_IO.Put (Item => "Initial distance (CM) away from apple > ");
  Ada.Float_Text_IO.Get(Item => InitialDist);
  Ada.Text_IO.New_Line;

  -- Cut the distance between the worm and the apple by
  -- the worm's body length until the worm is close enough
  -- to bite the apple

  Distance := InitialDist;             -- initialize
  LOOP
    EXIT WHEN Distance <= WormLength;  -- test for exit

    Ada.Text_IO.Put(Item => "The distance is ");
    Ada.Float_Text_IO.Put
      (Item => Distance, Fore => 4, Aft => 2, Exp => 0);
    Ada.Text_IO.New_Line;

    Distance := Distance - WormLength; -- update
  END LOOP;

  -- Display final distance before entering the apple.
  Ada.Text_IO.New_Line;
  Ada.Text_IO.Put (Item => "Final distance between worm and apple is ");
  Ada.Float_Text_IO.Put(Item => Distance, Fore => 4, Aft => 2, Exp => 0);
  Ada.Text_IO.New_Line;
  Ada.Text_IO.Put(Item => "The worm bites the apple.");
  Ada.Text_IO.New_Line;

END Worm_and_Apple;


